@@ -52,7 +52,7 @@ fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
 }
 
 fn on_misc_msg(msg: &str) -> MiscMessage {
-    let obj = serde_json::from_str::<HashMap<String, Value>>(&msg).unwrap();
+    let obj = serde_json::from_str::<HashMap<String, Value>>(msg).unwrap();
     let code = obj.get("code").unwrap().as_str().unwrap();
     let code = code.parse::<i64>().unwrap();
     if code < 10000 {
