@@ -26,15 +26,14 @@ pub struct DeribitWSClient<'a> {
 }
 
 fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
-    let channels_to_parse: Vec<&String> =
-        channels.iter().filter(|ch| !ch.starts_with('{')).collect();
+    let channels_to_parse = channels.iter().filter(|ch| !ch.starts_with('{'));
     let mut all_commands: Vec<String> = channels
         .iter()
         .filter(|ch| ch.starts_with('{'))
         .map(|s| s.to_string())
         .collect();
 
-    if !channels_to_parse.is_empty() {
+    if channels_to_parse.count() > 0 {
         all_commands.append(&mut vec![format!(
             r#"{{"method": "public/{}", "params": {{"channels": {}}}}}"#,
             if subscribe {
@@ -53,7 +52,7 @@ fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
 }
 
 fn on_misc_msg(msg: &str) -> MiscMessage {
-    let obj = serde_json::from_str::<HashMap<String, Value>>(&msg).unwrap();
+    let obj = serde_json::from_str::<HashMap<String, Value>>(msg).unwrap();
 
     if obj.contains_key("error") {
         error!("Received {} from {}", msg, EXCHANGE_NAME);
